@@ -85,7 +85,6 @@ void Array::_duplicate(const Array &a)
     else {
         d_maps = 0;
     }
-    // d_maps = a.d_maps ? new D4Maps(*(a.d_maps)) : 0;
 }
 
 // The first method of calculating length works when only one dimension is
@@ -104,11 +103,6 @@ void Array::update_length(int)
 {
     int length = 1;
     for (Dim_citer i = _shape.begin(); i != _shape.end(); i++) {
-#if 0
-        // If the size of any dimension is zero, then the array is not
-        // capable of storing any values. jhrg 1/28/16
-        length *= (*i).c_size > 0 ? (*i).c_size : 1;
-#endif
         length *= (*i).c_size;
     }
 
@@ -181,11 +175,8 @@ Array &
 Array::operator=(const Array &rhs)
 {
     if (this == &rhs) return *this;
-
-    dynamic_cast<Vector &>(*this) = rhs;
-
+    Vector::operator=(rhs);
     _duplicate(rhs);
-
     return *this;
 }
 
