@@ -113,11 +113,8 @@ Byte & Byte::operator=(const Byte & rhs)
 {
     if (this == &rhs)
         return *this;
-
-    dynamic_cast < BaseType & >(*this) = rhs;
-
+    BaseType::operator=(rhs);
     d_buf = rhs.d_buf;
-
     return *this;
 }
 
