@@ -24,7 +24,7 @@
 
 #include "config.h"
 
-//#define DODS_DEBUG
+#include <algorithm>
 
 #include "D4Attributes.h"
 #include "D4AttributeType.h"
@@ -475,6 +475,59 @@ D4Attributes::get(const string &fqn)
     return 0;
 }
 
+/**
+ * @brief Erase an attribute from a specific container
+ * This method expects to find 'name' in the D4Attributes object
+ * on which it is called.
+ * @param name The name of the attribute in this container
+ * @see void D4Attributes::erase(const string &fqn) for code that
+ * searches for a fully qualified attribute name and erases it.
+ */
+void
+D4Attributes::erase_named_attribute(const string &name)
+{
+    for (auto &attr: d_attrs) {
+        if (attr->name() == name) {
+            delete attr;
+            attr = nullptr;
+        }
+    }
+    d_attrs.erase(remove(d_attrs.begin(), d_attrs.end(), nullptr), d_attrs.end());
+}
+
+/**
+ * @brief Erase the given attribute.
+ * @param fqn Fully Qualified Name for the attribute to remove.
+ */
+void
+D4Attributes::erase(const string &fqn)
+{
+    // name1.name2.name3; part is name1 and rest is name2.name3
+    // name1; part is name1 and rest is ""
+    // name1.name2; part is name1 and rest is name2
+    size_t pos = fqn.find('.');
+    string part = fqn.substr(0, pos);
+    string rest= "";
+
+    if (pos != string::npos)
+        rest = fqn.substr(pos + 1);
+
+    if (!part.empty()) {
+        if (!rest.empty()) {
+            // in this case, we are not looking for a leaf node, so descend the
+            // attribute container hierarchy.
+            for (auto &a: d_attrs) {
+                if (a->name() == part && a->type() == attr_container_c) {
+                    a->attributes()->erase(rest);
+                }
+            }
+        }
+        else {
+            erase_named_attribute(part);
+        }
+    }
+}
+
 void
 D4Attribute::print_dap4(XMLWriter &xml) const
 {
