@@ -42,7 +42,7 @@ class D4Group;
 class D4EnumDef {
     string d_name;
     Type d_type;
-    D4EnumDefs *d_parent;
+    D4EnumDefs *d_parent; // a weak pointer, do not delete
 
     struct tuple {
         string label;
@@ -72,6 +72,14 @@ public:
         m_duplicate(rhs);
     }
 
+    virtual ~D4EnumDef() { }
+
+    D4EnumDef &operator=(const D4EnumDef &rhs) {
+        if (this == &rhs) return *this;
+        m_duplicate(rhs);
+        return *this;
+    }
+
     string name() const { return d_name; }
     void set_name(const string &n) { d_name = n; }
 
