@@ -52,12 +52,8 @@ D4Opaque::operator=(const D4Opaque &rhs)
 {
     if (this == &rhs)
         return *this;
-
-    // Call BaseType::operator=
-    dynamic_cast<BaseType &>(*this) = rhs;
-
+    BaseType::operator=(rhs);
     d_buf = rhs.d_buf;
-
     return *this;
 }
 
@@ -75,7 +71,7 @@ D4Opaque::clear_local_data()
 void
 D4Opaque::compute_checksum(Crc32 &checksum)
 {
-	checksum.AddData(&d_buf[0], d_buf.size());
+	checksum.AddData(d_buf.data(), d_buf.size());
 }
 
 void
@@ -84,7 +80,7 @@ D4Opaque::serialize(D4StreamMarshaller &m, DMR &, bool)
     if (!read_p())
         read();          // read() throws Error
 
-    m.put_opaque_dap4( reinterpret_cast<char*>(&d_buf[0]), d_buf.size() ) ;
+    m.put_opaque_dap4( reinterpret_cast<char*>(d_buf.data()), d_buf.size() ) ;
 
 #ifdef CLEAR_LOCAL_DATA
     clear_local_data();
