@@ -37,6 +37,7 @@
 
 #include <iostream>
 #include <sstream>
+#include <memory>
 
 //#define DODS_DEBUG
 //#define DODS_DEBUG2
@@ -160,20 +161,6 @@ DMR::DMR(D4BaseTypeFactory *factory, DDS &dds)
     set_dap_version("4.0");
 
     build_using_dds(dds);
-#if 0
-    for (DDS::Vars_iter i = dds.var_begin(), e = dds.var_end(); i != e; ++i) {
-    	BaseType *new_var = (*i)->transform_to_dap4(root() /*group*/, root() /*container*/);
-    	// If the variable being transformed is a Grid,
-    	// then Grid::transform_to_dap4() will add all the arrays to the
-    	// container (root() in this case) and return null, indicating that
-    	// this code does not need to do anything to add the transformed variable.
-    	if (new_var)
-    		root()->add_var_nocopy(new_var);
-    }
-
-    // Now copy the global attributes
-    root()->attributes()->transform_to_dap4(dds.get_attr_table());
-#endif
 }
 
 /**
@@ -202,9 +189,7 @@ DMR::DMR(const DMR &rhs) : DapObj()
  */
 DMR::~DMR()
 {
-#if 1
     delete d_root;
-#endif
 }
 
 DMR &
@@ -212,9 +197,7 @@ DMR::operator=(const DMR &rhs)
 {
     if (this == &rhs)
         return *this;
-
     m_duplicate(rhs);
-
     return *this;
 }
 
@@ -258,103 +241,6 @@ void DMR::build_using_dds(DDS &dds)
     root()->attributes()->transform_to_dap4(dds.get_attr_table());
 }
 
-#if 0
-/**
- * If we have a DMR that includes Attributes, use it to build the DDS. This
- * will copy all of the variables in the DMR into the DDS using
- * BaseType::transform_to_dap2(), so the actual types added can be
- * controlled by code that specializes the various type classes.
- *
- * @todo Fix this so that it does not take a reference to a DMR - since
- * this is a method of DMR and seems to operate on *this.
- *
- * @param dds Read variables and Attributes from this DDS
- */
-DDS *DMR::getDDS(DMR &dmr)
-{
-    DBG( cerr << __func__ << "() - BEGIN" << endl);
-    D4Group *root = dmr.root();
-
-    BaseTypeFactory *btf = new BaseTypeFactory();
-    DDS *dds = new DDS(btf, dmr.name());
-    dds->filename(dmr.filename());
-    AttrTable *dds_at = &(dds->get_attr_table());
-
-    // Now copy the global attributes
-    // D4Attributes::load_AttrTable(dds_at,root->attributes());
-
-    // TODO Make this a unique_ptr<> and let the compiler delete it. jhrg 6/17/19
-    vector<BaseType *> *top_vars = root->transform_to_dap2(dds_at, true);
-    vector<BaseType *>::iterator vIter = top_vars->begin();
-    vector<BaseType *>::iterator vEnd = top_vars->end();
-    for (; vIter != vEnd; vIter++) {
-        dds->add_var_nocopy(*vIter);
-    }
-    delete top_vars;
-
-#if 0
-    set<string> shared_dim_candidates;
-
-    vector<BaseType *> dropped_vars;
-    for (D4Group::Vars_iter i = root->var_begin(), e = root->var_end(); i != e; ++i)
-    {
-        DBG( cerr << __func__ << "() - Processing top level variable '"<< (*i)->type_name() << " " << (*i)->name() << "' to DDS." << endl; );
-        vector<BaseType *> *new_vars = (*i)->transform_to_dap2(&(dds->get_attr_table()));
-        if(new_vars!=0) {
-            vector<BaseType*>::iterator vIter = new_vars->begin();
-            vector<BaseType*>::iterator end = new_vars->end();
-            for(; vIter!=end; vIter++ ) {
-                BaseType *new_var = (*vIter);
-                DBG( cerr << __func__ << "() - Adding variable name: '"<< new_var->name() << "' " <<
-                    "type: " << new_var->type() << " " <<
-                    "type_name: " << new_var->type_name() << " to DDS." << endl; );
-                dds->add_var_nocopy(new_var);
-                Grid *grid = dynamic_cast <Grid *>(new_var);
-                if(grid) {
-                    Grid::Map_iter m = grid->map_begin();
-                    for(; m != grid->map_end(); m++) {
-                        shared_dim_candidates.insert((*m)->name());
-                    }
-                }
-                (*vIter) = 0;
-            }
-            delete new_vars;
-        }
-        else {
-            DBG( cerr << __func__ << "Adding variable '"<< (*i)->type_name() << " " << (*i)->name() << "' to drop list." << endl; );
-            dropped_vars.push_back((*i));
-        }
-    }
-    AttrTable *dv_table = Constructor::make_dropped_vars_attr_table(&dropped_vars);
-    if(dv_table) {
-        DBG( cerr << __func__ << "() - Adding dropped variable AttrTable." << endl);
-        dds_at->append_container(dv_table,dv_table->get_name());
-    }
-
-    // Get all the child groups.
-    D4Group::groupsIter gIter = root->grp_begin();
-    D4Group::groupsIter gEnd = root->grp_end();
-    for(; gIter!=gEnd; gIter++) {
-        D4Group *grp = *gIter;
-        DBG( cerr << __func__ << "() - Processing D4Group " << grp->name() << endl);
-        vector<BaseType *> *d2_vars = grp->transform_to_dap2(dds_at);
-        if(d2_vars) {
-            DBG( cerr << __func__ << "() - Processing " << grp->name() << " Member Variables." << endl);
-            vector<BaseType *>::iterator vIter = d2_vars->begin();
-            vector<BaseType *>::iterator vEnd = d2_vars->end();
-            for(; vIter!=vEnd; vIter++) {
-                DBG( cerr << __func__ << "() - Processing " << grp->name() << " Member Variable: " << (*vIter)->name() << endl);
-                dds->add_var(*vIter);
-            }
-        }
-    }
-#endif
-
-    DBG( cerr << __func__ << "() - END" << endl);
-    return dds;
-}
-#endif
-
 /**
  * @brief Build a DDS from a DMR
  *
@@ -373,31 +259,31 @@ DDS *DMR::getDDS(DMR &dmr)
 DDS *
 DMR::getDDS()
 {
-#if 0
-    return DMR::getDDS(*this);
-#else
     DBG( cerr << __func__ << "() - BEGIN" << endl);
 
-#if 0
-    BaseTypeFactory *btf = new BaseTypeFactory();
-#endif
     BaseTypeFactory btf;
     DDS *dds = new DDS(&btf, name());
     dds->filename(filename());
 
     // Now copy the global attributes
     // TODO Make this a unique_ptr<> and let the compiler delete it. jhrg 6/17/19
+    // change made jhrg 2/4/22
+#if 1
+    unique_ptr< vector<BaseType *>> top_vars(root()->transform_to_dap2(&(dds->get_attr_table())/*, true*/));
+    for (vector<BaseType *>::iterator i = top_vars->begin(), e = top_vars->end(); i != e; i++) {
+        dds->add_var_nocopy(*i);
+    }
+#else
     vector<BaseType *> *top_vars = root()->transform_to_dap2(&(dds->get_attr_table())/*, true*/);
     for (vector<BaseType *>::iterator i = top_vars->begin(), e = top_vars->end(); i != e; i++) {
         dds->add_var_nocopy(*i);
     }
     delete top_vars;
-
+#endif
     DBG( cerr << __func__ << "() - END" << endl);
     
     dds->set_factory(0);
     return dds;
-#endif
 }
 
 /**
@@ -463,8 +349,9 @@ DMR::set_dap_version(const string &v)
  * @param constrained Should the size of the whole DMR be used or should the
  * current constraint be taken into account?
  * @return The size of the request in kilobytes
+ * @deprecated "Use DMR::request_size_kb()"
  */
-[[deprecated("Use DMR::request_size_kb()")]]
+//[[deprecated("Use DMR::request_size_kb()")]]
 long DMR::request_size(bool constrained)
 {
     return d_root->request_size(constrained);
