@@ -35,8 +35,6 @@
 
 #include "config.h"
 
-// #define DODS_DEBUG
-
 #include <sstream>
 #include <functional>
 #include <algorithm>
@@ -56,6 +54,8 @@
 #include "D4Maps.h"
 #include "D4Attributes.h"
 
+#include "DapIndent.h"
+
 using namespace std;
 
 namespace libdap {
@@ -63,13 +63,7 @@ namespace libdap {
 void
 Grid::m_duplicate(const Grid &s)
 {
-    // TODO revisit this code once/if the class is switched from using it's
-    // own vars to those in Constructor. jhrg 4/3/13
-
-	// copy the weak pointer - Constructor will take care of copying
-	// the 'strong' pointers.
-	//d_array_var = s.d_array_var;
-	d_is_array_set = s.d_is_array_set;
+    d_is_array_set = s.d_is_array_set;
 }
 
 /** The Grid constructor requires only the name of the variable
@@ -121,21 +115,8 @@ Grid::operator=(const Grid &rhs)
 {
     if (this == &rhs)
         return *this;
-
-    // Removed this; it makes this operator= work differently than the rest
-#if 0
-    delete d_array_var; d_array_var = 0;
-
-    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
-        BaseType *btp = *i ;
-        delete btp ;
-    }
-#endif
-
-    dynamic_cast<Constructor &>(*this) = rhs;
-
+    Constructor::operator=(rhs);
     m_duplicate(rhs);
-
     return *this;
 }
 
@@ -154,10 +135,10 @@ Grid::transform_to_dap4(D4Group *root, Constructor *container)
     vector<Array*> d4_map_arrays;
 
     // We do the Map Arrays first because some people expect to see them
-    // delclared prior to the coverage array the utilizes them - even though that
+    // declared prior to the coverage array the utilizes them - even though that
     // is not a requirement of DAP4 I did it here to make people happier.
 	// We add the maps arrays to the current container if needed and make a
-    // a vector of them so we can add D4Map objects to our Precious down
+    // vector of them so that we can add D4Map objects to our Precious down
     // below.
 	for (Map_iter i = map_begin(), e = map_end(); i != e; ++i) {
 	    DBG(cerr << __func__ << "() - Processing Map Array:  '"<< (*i)->name() << "' ("<< (void *)(*i)<< ")" << endl;);
@@ -166,7 +147,7 @@ Grid::transform_to_dap4(D4Group *root, Constructor *container)
 	    // the same name is good enough. The point here is to be sure to only use the
 	    // existing maps. This is an important issue when there are multiple Grids in the same
 	    // dataset that utilize the same Map arrays data.
-        Array *the_map_array;;
+        Array *the_map_array;
         Array *container_map_array = static_cast<Array*>(container->var((*i)->name()));
         if(!container_map_array){
             DBG(cerr << __func__ << "() - No Map Array '" << (*i)->name() << "' present in the current DAP4 container ("<<container->name()<< ":"<<(void*)container<< "). Let's fix that..." << endl;);
@@ -498,15 +479,7 @@ Grid::prepend_map(Array* p_new_map, bool add_copy)
 BaseType *
 Grid::array_var()
 {
-    //return d_array_var;
-	// FIXME Should really test that the array has not be set; maps might be added first. jhrg 5/9/13
-#if 0
-	if (d_array_var)
-		cerr << "In array_var(), d_array_var holds a " << d_array_var->type_name() << endl;
-	else
-		cerr << "In array_var(), d_array_var is null" << endl;
-#endif
-	return d_is_array_set /*d_vars.size() > 0*/ ? *d_vars.begin() : 0;
+	return d_is_array_set ? *d_vars.begin() : nullptr;
 }
 
 /** @brief Returns the Grid Array.
@@ -526,7 +499,7 @@ Grid::map_begin()
     // d_var vector<BaseType*> of Constructor _unless_ the Array part
     // has yet to be set. In the latter case, there are only maps in
     // d_vars
-    return d_is_array_set/*(d_array_var != 0)*/ ? d_vars.begin() + 1: d_vars.begin();
+    return d_is_array_set ? d_vars.begin() + 1: d_vars.begin();
 }
 
 /** Returns an iterator referencing the end of the list of Map vectors.
@@ -542,7 +515,6 @@ Grid::Map_riter
 Grid::map_rbegin()
 {
     // see above
-    // return d_is_array_set/*(d_array_var != 0)*/ ? d_vars.rbegin() + 1: d_vars.rbegin();
     return d_vars.rbegin();
 }
 
@@ -560,8 +532,7 @@ Grid::map_rend()
 Grid::Map_iter
 Grid::get_map_iter(int i)
 {
-    // return map_begin() + i;
-    return d_is_array_set ? map_begin() + 1 + i : map_begin() + i;
+    return d_is_array_set ? d_vars.begin() + 1 + i : d_vars.begin() + i;
 }
 
 /** Returns the number of components in the Grid object.  This is
@@ -600,35 +571,42 @@ Grid::components(bool constrained)
     return comp;
 }
 
+/**
+ * All the attributes in a AttrTable for a Grid go in AttrTable for the Array.
+ *
+ * @param at_container
+ */
 void Grid::transfer_attributes(AttrTable *at_container)
 {
     DBG( cerr << __func__ << "() - BEGIN "<< type_name() << " " << name() << " (at_container:"<< at_container->get_name() << ":"<<(void*)at_container<< ")" << endl;);
 
-    // At should be the attribute table for the Grid
+    // The variable 'at' should be the attribute table for the Grid
 	AttrTable *at = at_container->get_attr_table(name());
 	if (at) {
 	    DBG( cerr << __func__ << "() - Found AttrTable ("<< at->get_name() << ":" << (void*)at<< ")" << endl;);
 		at->set_is_global_attribute(false);
 
-		// We don't monkey with the data array attributes because it usually just makes
-		// a mess. but:
-		// TODO We should come back and decide if we want to but configuration
-		// controls on this or do something smarter like check for duplicate values
-		// before merging the Array metadata into the Grid metadata
-		// SO - We don't copy the attributes like we used to:
+#if 0
+		// Removing this is left over from a previous version, unknown date.
+		// If the line is added back, some of the DMR round trip tests fail
+		// and the dapreader behavior is changed - tests that build responses
+		// from .dods and .das files fail when they include Grids. jhrg 5/23/18
 		//
-		//    array_var()->transfer_attributes(at);
-		//
-		// And then to seal the deal we have to
-		// Mark them as not "global" so they don't get copied.
-		AttrTable *dvat = at->get_attr_table(array_var()->name());
-		if(dvat){
-		    dvat->set_is_global_attribute(false);
-		}
+		// See also HYARX-766
+		array_var()->transfer_attributes(at);
+#endif
+
+		// If the AttrTable with the name of this Grid (which is also the
+        // name of the Grid's Array) contains a child AttrTable with that
+        // name, mark the attributes as 'not global' and ignore them. This
+        // code has been here for some time; I just added this comment. jhrg 5/23/18
+        AttrTable *dvat = at->get_attr_table(array_var()->name());
+        if (dvat) {
+            dvat->set_is_global_attribute(false);
+        }
 
 		Map_iter map = map_begin();
 		while (map != map_end()) {
-	        DBG( cerr << __func__ << "() - Processing Map Array ("<< (*map)->name() << ":" << (void*)(*map)<< ")" << endl;);
 			(*map)->transfer_attributes(at);
 			map++;
 		}
