@@ -532,6 +532,9 @@ bool
 HTTPConnect::url_uses_proxy_for(const string &url)
 {
     if (d_rcr->is_proxy_for_used()) {
+        // NB: This could be improved by moving the Regex instance into
+        // the RCReader class, but the proxy stuff is all deprecated.
+        // jhrg 12/1/21
         Regex host_regex(d_rcr->get_proxy_for_regexp().c_str());
         int index = 0, matchlen;
         return host_regex.search(url.c_str(), url.size(), matchlen, index) != -1;
@@ -726,7 +729,7 @@ get_tempfile_template(const string &file_template)
 
 #else	// Unix/Linux/OSX has another...
     // white list for a directory
-    Regex directory("[-a-zA-Z0-9_/]*");
+    const Regex directory("[-a-zA-Z0-9_/]*");
 #ifdef USE_GETENV
     c = getenv("TMPDIR");
     if (directory.match(c.c_str(), c.length()) && (access(c.c_str(), W_OK | R_OK) == 0))
@@ -787,19 +790,19 @@ get_temp_file(FILE *&stream) throw(Error)
 
     vector<char> pathname(dods_temp.length() + 1);
 
-    strncpy(&pathname[0], dods_temp.c_str(), dods_temp.length());
+    strncpy(pathname.data(), dods_temp.c_str(), dods_temp.length());
 
-    DBG(cerr << "pathanme: " << &pathname[0] << " (" << dods_temp.length() + 1 << ")" << endl);
+    DBG(cerr << "pathanme: " << pathname.data() << " (" << dods_temp.length() + 1 << ")" << endl);
 
     // Open truncated for update. NB: mkstemp() returns a file descriptor.
 #if defined(WIN32) || defined(TEST_WIN32_TEMPS)
-    stream = fopen(_mktemp(&pathname[0]), "w+b");
+    stream = fopen(_mktemp(pathname.data()), "w+b");
 #else
     // Make sure that temp files are accessible only by the owner.
     int mask = umask(077);
     if (mask < 0)
         throw Error("Could not set the file creation mask: " + string(strerror(errno)));
-    int fd = mkstemp(&pathname[0]);
+    int fd = mkstemp(pathname.data());
     if (fd < 0)
         throw Error("Could not create a temporary file to store the response: " + string(strerror(errno)));
 
@@ -810,7 +813,7 @@ get_temp_file(FILE *&stream) throw(Error)
     if (!stream)
     	throw Error("Failed to open a temporary file for the data values (" + dods_temp + ")");
 
-    dods_temp = &pathname[0];
+    dods_temp = pathname.data();
     return dods_temp;
 }
 
