@@ -258,11 +258,8 @@ Sequence &
 Sequence::operator=(const Sequence &rhs)
 {
     if (this == &rhs) return *this;
-
-    dynamic_cast<Constructor &>(*this) = rhs; // run Constructor=
-
+    Constructor::operator=(rhs);
     m_duplicate(rhs);
-
     return *this;
 }
 
