@@ -105,11 +105,8 @@ UInt16::operator=(const UInt16 &rhs)
 {
     if (this == &rhs)
         return *this;
-
-    dynamic_cast<BaseType &>(*this) = rhs;
-
+    BaseType::operator=(rhs);
     d_buf = rhs.d_buf;
-
     return *this;
 }
 
