@@ -106,11 +106,8 @@ UInt32::operator=(const UInt32 &rhs)
 {
     if (this == &rhs)
         return *this;
-
-    dynamic_cast<BaseType &>(*this) = rhs;
-
+    BaseType::operator=(rhs);
     d_buf = rhs.d_buf;
-
     return *this;
 }
 
