@@ -80,15 +80,17 @@ void Vector::m_duplicate(const Vector & v)
     // _var holds the type of the elements. That is, it holds a BaseType
     // which acts as a template for the type of each element.
     if (v.d_proto) {
+	    // Vector manages this ptr, delete before assigning a new object. jhrg 2/19/22
+	    if (d_proto) delete d_proto;
         d_proto = v.d_proto->ptr_duplicate(); // use ptr_duplicate()
         d_proto->set_parent(this); // ptr_duplicate does not set d_parent.
     }
     else {
-        d_proto = 0;
+        d_proto = nullptr;
     }
 
     // d_compound_buf and d_buf (further down) hold the values of the Vector. The field
-    // d_compound_buf is used when the Vector holds non-numeric data (including strings
+    // d_compound_buf is used when the Vector holds non-numeric data (including strings,
     // although it used to be that was not the case jhrg 2/10/05) while d_buf
     // holds numeric values.
     if (v.d_compound_buf.empty()) {
@@ -208,7 +210,7 @@ unsigned int Vector::m_create_cardinal_data_buffer_for_type(unsigned int numElts
 void Vector::m_delete_cardinal_data_buffer()
 {
 	delete[] d_buf;
-	d_buf = 0;
+	d_buf = nullptr;
 	d_capacity = 0;
 }
 
@@ -226,7 +228,8 @@ void Vector::m_set_cardinal_values_internal(const CardType* fromArray, int numEl
     }
     set_length(numElts);
     m_create_cardinal_data_buffer_for_type(numElts);
-    memcpy(d_buf, fromArray, numElts * sizeof(CardType));
+    if (d_buf)
+        memcpy(d_buf, fromArray, numElts * sizeof(CardType));
     set_read_p(true);
 }
 
@@ -246,7 +249,7 @@ void Vector::m_set_cardinal_values_internal(const CardType* fromArray, int numEl
  @see Type
  @brief The Vector constructor.  */
 Vector::Vector(const string & n, BaseType * v, const Type & t, bool is_dap4 /* default:false */) :
-    BaseType(n, t, is_dap4), d_length(-1), d_proto(0), d_buf(0), d_compound_buf(0), d_capacity(0)
+    BaseType(n, t, is_dap4)
 {
     if (v)
         add_var(v);
@@ -275,7 +278,7 @@ Vector::Vector(const string & n, BaseType * v, const Type & t, bool is_dap4 /* d
  @see Type
  @brief The Vector constructor.  */
 Vector::Vector(const string & n, const string &d, BaseType * v, const Type & t, bool is_dap4 /* default:false */) :
-    BaseType(n, d, t, is_dap4), d_length(-1), d_proto(0), d_buf(0), d_compound_buf(0), d_capacity(0)
+    BaseType(n, d, t, is_dap4)
 {
     if (v)
         add_var(v);
@@ -286,8 +289,8 @@ Vector::Vector(const string & n, const string &d, BaseType * v, const Type & t,
 }
 
 /** The Vector copy constructor. */
-Vector::Vector(const Vector & rhs) :
-    BaseType(rhs)
+Vector::Vector(const Vector & rhs) : BaseType(rhs)
+
 {
     DBG2(cerr << "Entering Vector const ctor for object: " << this <<
             endl); DBG2(cerr << "RHS: " << &rhs << endl);
@@ -300,7 +303,7 @@ Vector::~Vector()
     DBG2(cerr << "Entering ~Vector (" << this << ")" << endl);
 
     delete d_proto;
-    d_proto = 0;
+    d_proto = nullptr;
 
     // Clears all buffers
     clear_local_data();
@@ -312,11 +315,8 @@ Vector & Vector::operator=(const Vector & rhs)
 {
     if (this == &rhs)
         return *this;
-
-    dynamic_cast<BaseType &> (*this) = rhs;
-
+    BaseType::operator=(rhs);
     m_duplicate(rhs);
-
     return *this;
 }
 
@@ -929,7 +929,7 @@ void Vector::intern_data(/*Crc32 &checksum, DMR &dmr, ConstraintEvaluator &eval*
         case dods_opaque_c:
         case dods_structure_c:
         case dods_sequence_c:
-            // Modified the assert here from '... != 0' to '... >= length())
+            // Modified the assertion here from '... != 0' to '... >= length())
             // to accommodate the case of a zero-length array. jhrg 1/28/16
             assert(d_compound_buf.capacity() >= (unsigned)length());
 
@@ -1184,7 +1184,8 @@ unsigned int Vector::val2buf(void *val, bool reuse)
                 m_create_cardinal_data_buffer_for_type(length());
 
             // width(true) returns the size in bytes given the constraint
-            memcpy(d_buf, val, width(true));
+            if (d_buf)
+                memcpy(d_buf, val, width(true));
             break;
 
         case dods_str_c:
@@ -1256,7 +1257,7 @@ unsigned int Vector::buf2val(void **val)
 
     // This is the width computed using length(). The
     // length() property is changed when a projection
-    // constraint is applied. Thus this is the number of
+    // constraint is applied. Thus, this is the number of
     // bytes in the buffer given the current constraint.
 
     switch (d_proto->type()) {
@@ -1371,7 +1372,7 @@ void Vector::set_vec_nocopy(unsigned int i, BaseType * val)
  * Remove any read or set data in the private data of this Vector,
  * setting read_p() to false.
  * Essentially clears the _buf, d_str, and d_compound_buf of any data.
- * Useful for tightening up memory when the data is no longer needed,
+ * Useful for tightening up memory when the data are no longer needed,
  * but the object cannot yet be destroyed.
  *
  * On exit: get_value_capacity() == 0 && !read_p()
@@ -1737,7 +1738,7 @@ bool Vector::set_value(string *val, int sz)
 template<typename T>
 bool Vector::set_value_worker(vector<T> &v, int sz)
 {
-    return set_value(&v[0], sz);
+    return set_value(v.data(), sz);
 }
 
 bool Vector::set_value(vector<dods_byte> &val, int sz)
