@@ -26,7 +26,7 @@
 #include <sstream>
 #include <iterator>
 
-//#define DODS_DEBUG
+//#define DODS_DEBUG 
 
 #include "D4CEScanner.h"
 #include "D4ConstraintEvaluator.h"
@@ -58,8 +58,10 @@ namespace libdap {
 
 bool D4ConstraintEvaluator::parse(const std::string &expr)
 {
+    
     d_expr = expr;	// set for error messages. See the %initial-action section of .yy
 
+    DBG(cerr << "Entering D4ConstraintEvaluator::parse: "  << endl);
     std::istringstream iss(expr);
     D4CEScanner scanner(iss);
     D4CEParser parser(scanner, *this /* driver */);
@@ -69,6 +71,9 @@ bool D4ConstraintEvaluator::parse(const std::string &expr)
         parser.set_debug_stream(std::cerr);
     }
 
+    if(expr.empty()) 
+        d_dmr->set_ce_empty(true);
+
     return parser.parse() == 0;
 }
 
@@ -305,25 +310,35 @@ D4ConstraintEvaluator::slice_dimension(const std::string &id, const index &i)
 
 D4ConstraintEvaluator::index D4ConstraintEvaluator::make_index(const std::string &i)
 {
-    unsigned long long v = get_int64(i.c_str());
+    unsigned long long v = get_uint64(i.c_str());
     return index(v, 1, v, false, false /*empty*/, "");
 }
 
 D4ConstraintEvaluator::index D4ConstraintEvaluator::make_index(const std::string &i, const std::string &s,
     const std::string &e)
 {
-    return index(get_int64(i.c_str()), get_int64(s.c_str()), get_int64(e.c_str()), false, false /*empty*/, "");
+    int64_t initial = get_uint64(i.c_str());
+    int64_t end = get_uint64(e.c_str());
+    if (initial > end)
+        throw Error(malformed_expr, string("The start value of an array index is past the stop value."));
+
+    return index(initial, get_uint64(s.c_str()), end, false, false /*empty*/, "");
 }
 
 D4ConstraintEvaluator::index D4ConstraintEvaluator::make_index(const std::string &i, unsigned long long s,
     const std::string &e)
 {
-    return index(get_int64(i.c_str()), s, get_int64(e.c_str()), false, false /*empty*/, "");
+    int64_t initial = get_uint64(i.c_str());
+    int64_t end = get_uint64(e.c_str());
+    if (initial > end)
+        throw Error(malformed_expr, string("The start value of an array index is past the stop value."));
+
+    return index(initial, s, end, false, false /*empty*/, "");
 }
 
 D4ConstraintEvaluator::index D4ConstraintEvaluator::make_index(const std::string &i, const std::string &s)
 {
-    return index(get_int64(i.c_str()), get_int64(s.c_str()), 0, true, false /*empty*/, "");
+    return index(get_uint64(i.c_str()), get_uint64(s.c_str()), 0, true, false /*empty*/, "");
 }
 
 D4ConstraintEvaluator::index D4ConstraintEvaluator::make_index(const std::string &i, unsigned long long s)
