@@ -43,10 +43,7 @@
 #include <cstring>
 #include <string>
 #include <sstream>
-
-#include <cstdio> //SBL 12.3.19
-
-#include "GetOpt.h"
+#include <unistd.h>     // getopt
 
 #include "DMR.h"
 #include "XMLWriter.h"
@@ -59,61 +56,55 @@
 #include "RCReader.h"
 
 using namespace std;
-using namespace libdap ;
+using namespace libdap;
 
 const char *version = CVER " (" DVR " DAP/" DAP_PROTOCOL_VERSION ")";
-#if 0
-extern int libdap::dods_keep_temps;     // defined in HTTPResponse.h
-extern int libdap::www_trace;
-#endif
-static void usage(const string &name)
+
+static void usage(const string &)
 {
-	cerr << "Usage: " << name << endl;
-	cerr << " [dD vVikmzstM][-c <expr>][-m <num>] <url> [<url> ...] | <file> [<file> ...]" << endl;
-	cerr << endl;
-	cerr << "In the first form of the command, dereference the URL and" << endl;
-	cerr << "perform the requested operations. This includes routing" << endl;
-	cerr << "the returned information through the DAP processing" << endl;
-	cerr << "library (parsing the returned objects, et c.). If none" << endl;
-	cerr << "of a, d, or D are used with a URL, then the DAP library" << endl;
-	cerr << "routines are NOT used and the URLs contents are dumped" << endl;
-	cerr << "to standard output." << endl;
-	cerr << "Note: If the URL contains a query string the query string" << endl;
-	cerr << "will be preserved in the request. However, if the query " << endl;
-	cerr << "string contains DAP4 keys they may interfere with the" << endl;
-	cerr << "operation of " << name << ". A warning will be" << endl;
-	cerr << "written to stderr when "<< name << " identifies" << endl;
-	cerr << "the presence of a DAP4 query key in the submitted" << endl;
-	cerr << "URL's query string." << endl;
-	cerr << endl;
-	cerr << "In the second form of the command, assume the files are" << endl;
-	cerr << "DataDDS objects (stored in files or read from pipes)" << endl;
-	cerr << "and process them as if -D were given. In this case the" << endl;
-	cerr << "information *must* contain valid MIME header in order" << endl;
-	cerr << "to be processed." << endl;
-	cerr << endl;
-	cerr << "Options:" << endl;
-    cerr << "        d: For each URL, get the (DAP4) DMR object. Does not get data." << endl;
-	cerr << "        D: For each URL, get the DAP4 Data response." << endl;
-	cerr << endl;
-	cerr << "        v: Verbose output." << endl;
-	cerr << "        V: Version of this client; see 'i' for server version." << endl;
-	cerr << "        i: For each URL, get the server version." << endl;
-	// cerr << "        k: Keep temporary files created by libdap." << endl;
-	cerr << "        m: Request the same URL <num> times." << endl;
-	cerr << "        z: Ask the server to compress data." << endl;
-	cerr << "        s: Print Sequences using numbered rows." << endl;
-	// cerr << "        t: Trace www accesses." << endl;
-	cerr << "        M: Assume data read from a file has no MIME headers; use only with files" << endl;
-	cerr << endl;
-	cerr << "        c: <expr> is a constraint expression. Used with -d/D" << endl;
-	cerr << "           NB: You can use a `?' for the CE also." << endl;
-    cerr << "        S: Used in conjunction with -d and will report the total size of the data "
-            "referenced in the DMR." << endl;
+    const char *message = R"(
+    Usage: getdap4 [dD vVmzsM][-c <expr>][-m <num>] <url> [<url> ...]
+           getdap4 [dD vVmzsM][-c <expr>][-m <num>] <file> [<file> ...]
+
+    In the first form of the command, dereference the URL and perform
+    the requested operations. This includes routing the returned
+    information through the DAP processing library (parsing the
+    returned objects, et c.). If none of d, or D are used with a URL,
+    then the DAP library routines are NOT used and the URLs contents
+    are dumped to standard output.
+
+    Note: If the URL contains a query string the query string will be
+    preserved in the request. However, if the query string contains
+    DAP4 keys they may interfere with the operation of getdap4. A
+    warning will be written to stderr when getdap4 identifies the
+    presence of a DAP4 query key in the submitted URL's query string.
+
+    In the second form of the command, assume the files are DAP4 data
+    responses (stored in files or read from pipes)
+
+    Options: 
+            d: For each URL, get the (DAP4) DMR object. Does not get data. 
+            D: For each URL, get the DAP4 Data response. 
+
+            v: Verbose output. 
+            V: Version of this client 
+            i: For each URL, get the server version. 
+            m: Request the same URL <num> times. 
+            z: Ask the server to compress data. 
+            s: Print Sequences using numbered rows. 
+            M: Assume data read from a file has no MIME headers; use only 
+               with files 
+
+            c: <expr> is a constraint expression. Used with -d/D 
+               NB: You can use a `?' for the CE also. 
+            S: Used in conjunction with -d and will report the total size 
+               of the data referenced in the DMR.)";
+
+    cerr << message << endl;
 }
 
 // Used for raw http access/transfer
-bool read_data(FILE * fp)
+bool read_data(FILE *fp)
 {
     if (!fp) {
         fprintf(stderr, "getdap4: Whoa!!! Null stream pointer.\n");
@@ -129,23 +120,24 @@ bool read_data(FILE * fp)
     return true;
 }
 
-static void read_response_from_file(D4Connect *url, DMR &dmr, Response &r, bool mime_headers, bool get_dap4_data, bool get_dmr)
+static void
+read_response_from_file(D4Connect *url, DMR &dmr, Response &r, bool mime_headers, bool get_dap4_data, bool get_dmr)
 {
     if (mime_headers) {
-    	if (get_dap4_data)
-    		url->read_data(dmr, r);
-    	else if (get_dmr)
-    		url->read_dmr(dmr, r);
-    	else
-    		throw Error("Only supports Data or DMR responses");
+        if (get_dap4_data)
+            url->read_data(dmr, r);
+        else if (get_dmr)
+            url->read_dmr(dmr, r);
+        else
+            throw Error("Only supports Data or DMR responses");
     }
     else {
-    	if (get_dap4_data)
-    		url->read_data_no_mime(dmr, r);
-    	else if (get_dmr)
-    		url->read_dmr_no_mime(dmr, r);
-    	else
-    		throw Error("Only supports Data or DMR responses");
+        if (get_dap4_data)
+            url->read_data_no_mime(dmr, r);
+        else if (get_dmr)
+            url->read_dmr_no_mime(dmr, r);
+        else
+            throw Error("Only supports Data or DMR responses");
     }
 }
 
@@ -184,9 +176,9 @@ static void print_data(DMR &dmr, bool print_rows = false)
  *  @param constrained Should the size of the whole DDS be used or should the
  *  current constraint be taken into account?
  */
-unsigned long long get_size(D4Group *grp, bool constrained=false)
+unsigned long long get_size(D4Group *grp, bool constrained = false)
 {
-    unsigned long long  w = 0;
+    unsigned long long w = 0;
 
     for (auto var_itr = grp->var_begin(); var_itr != grp->var_end(); var_itr++) {
         if (constrained) {
@@ -197,27 +189,25 @@ unsigned long long get_size(D4Group *grp, bool constrained=false)
             w += (*var_itr)->width(constrained);
         }
     }
-    for(auto grp_itr = grp->grp_begin(); grp_itr != grp->grp_end(); grp_itr++){
-        w += get_size(*grp_itr,constrained);
+    for (auto grp_itr = grp->grp_begin(); grp_itr != grp->grp_end(); grp_itr++) {
+        w += get_size(*grp_itr, constrained);
     }
 
     return w;
 }
 
-unsigned long long get_size(DMR &dmr, bool constrained=false)
+unsigned long long get_size(DMR &dmr, bool constrained = false)
 {
-    return get_size(dmr.root(),constrained);
+    return get_size(dmr.root(), constrained);
 }
 
 
 int main(int argc, char *argv[])
 {
-    GetOpt getopt(argc, argv, "[dDvVikrm:Mzstc:S]");
     int option_char;
 
     bool get_dmr = false;
     bool get_dap4_data = false;
-    bool get_version = false;
     bool cexpr = false;
     bool verbose = false;
     bool multi = false;
@@ -235,73 +225,60 @@ int main(int argc, char *argv[])
     _setmode(_fileno(stdout), _O_BINARY);
 #endif
 
-    while ((option_char = getopt()) != -1)
+    while ((option_char = getopt(argc, argv, "dDvVrm:Mzsc:S")) != -1) {
         switch (option_char) {
-        case 'd':
-            get_dmr = true;
-            break;
-        case 'D':
-            get_dap4_data = true;
-            break;
-        case 'v':
-            verbose = true;
-            break;
-        case 'V':
-        	cerr << "getdap4 version: " << version << endl;
-            exit(0);
-        case 'i':
-            get_version = true;
-            break;
-        case 'S':
-            compute_size = true;
-            break;
-#if 0
-        case 'k':
-            dods_keep_temps = 1;
-            break;              // keep_temp is in Connect.cc
-#endif
-        case 'r':
-        	report_errors = true;
-        	break;
-        case 'm':
-            multi = true;
-            times = atoi(getopt.optarg);
-            break;
-        case 'z':
-            accept_deflate = true;
-            break;
-        case 's':
-            print_rows = true;
-            break;
-        case 'M':
-            mime_headers = false;
-            break;
-#if 0
-        case 't':
-            www_trace = 1;
-            break;
-#endif
-        case 'c':
-            cexpr = true;
-            expr = getopt.optarg;
-            break;
-        case 'h':
-        case '?':
-        default:
-            usage(argv[0]);
-            exit(1);
+            case 'd':
+                get_dmr = true;
+                break;
+            case 'D':
+                get_dap4_data = true;
+                break;
+            case 'v':
+                verbose = true;
+                break;
+            case 'V':
+                cerr << "getdap4 version: " << version << endl;
+                exit(0);
+            case 'S':
+                compute_size = true;
+                break;
+            case 'r':
+                report_errors = true;
+                break;
+            case 'm':
+                multi = true;
+                times = atoi(optarg);
+                break;
+            case 'z':
+                accept_deflate = true;
+                break;
+            case 's':
+                print_rows = true;
+                break;
+            case 'M':
+                mime_headers = false;
+                break;
+            case 'c':
+                cexpr = true;
+                expr = optarg;
+                break;
+            case 'h':
+            case '?':
+            default:
+                usage(argv[0]);
+                exit(1);
         }
+    }
 
+    D4Connect *url = nullptr;
     try {
         // If after processing all the command line options there is nothing
         // left (no URL or file) assume that we should read from stdin.
-        for (int i = getopt.optind; i < argc; ++i) {
+        for (int i = optind; i < argc; ++i) {
             if (verbose)
                 cerr << "Fetching: " << argv[i] << endl;
 
             string name = argv[i];
-            D4Connect *url = 0;
-            // auto_ptr? jhrg 10/19/15
             url = new D4Connect(name);
 
             // This overrides the value set in the .dodsrc file.
@@ -328,18 +305,18 @@ int main(int argc, char *argv[])
                         read_response_from_file(url, dmr, r, mime_headers, get_dap4_data, get_dmr);
                     }
                     else {
-                    	fstream f(argv[i], std::ios_base::in);
-                    	if (!f.is_open() || f.bad() || f.eof())
-                    		throw Error((string)"Could not open: " + argv[i]);
+                        fstream f(argv[i], std::ios_base::in);
+                        if (!f.is_open() || f.bad() || f.eof())
+                            throw Error((string) "Could not open: " + argv[i]);
 
-                    	Response r(&f, 0);
+                        Response r(&f, 0);
 
                         read_response_from_file(url, dmr, r, mime_headers, get_dap4_data, get_dmr);
                     }
 
                     if (verbose)
                         cerr << "DAP version: " << url->get_protocol().c_str() << " Server version: "
-    						<< url->get_version().c_str() << endl;
+                             << url->get_version().c_str() << endl;
 
                     // Always write the DMR
                     XMLWriter xml;
@@ -347,11 +324,12 @@ int main(int argc, char *argv[])
                     cout << xml.get_doc() << endl;
 
                     if (get_dap4_data)
-                    	print_data(dmr, print_rows);
+                        print_data(dmr, print_rows);
                 }
-                catch (Error & e) {
+                catch (Error &e) {
                     cerr << "Error: " << e.get_error_message() << endl;
-                    delete url; url = 0;
+                    delete url;
+                    url = nullptr;
                     if (report_errors)
                         return EXIT_FAILURE;
                 }
@@ -364,50 +342,52 @@ int main(int argc, char *argv[])
                         url->request_dmr(dmr, expr);
 
                         if (verbose) {
-                            cout << "DAP version: " << url->get_protocol() << ", Server version: " << url->get_version() << endl;
+                            cout << "DAP version: " << url->get_protocol() << ", Server version: " << url->get_version()
+                                 << endl;
                             cout << "DMR:" << endl;
                         }
 
                         XMLWriter xml;
                         dmr.print_dap4(xml);
                         cout << xml.get_doc() << endl;
-                        if(compute_size){
+                        if (compute_size) {
                             cout << "DMR References " << get_size(dmr) << " bytes of data," << endl;
                         }
                     }
-                    catch (Error & e) {
+                    catch (Error &e) {
                         cerr << e.get_error_message() << endl;
                         if (report_errors)
-                        	return EXIT_FAILURE;
+                            return EXIT_FAILURE;
                         continue;       // Goto the next URL or exit the loop.
                     }
                 }
             }
             else if (get_dap4_data) {
-                 for (int j = 0; j < times; ++j) {
-                     D4BaseTypeFactory factory;
-                     DMR dmr(&factory);
-                     try {
-                         url->request_dap4_data(dmr, expr);
+                for (int j = 0; j < times; ++j) {
+                    D4BaseTypeFactory factory;
+                    DMR dmr(&factory);
+                    try {
+                        url->request_dap4_data(dmr, expr);
 
-                         if (verbose) {
-                             cout << "DAP version: " << url->get_protocol() << ", Server version: " << url->get_version() << endl;
-                             cout << "DMR:" << endl;
-                         }
+                        if (verbose) {
+                            cout << "DAP version: " << url->get_protocol() << ", Server version: " << url->get_version()
+                                 << endl;
+                            cout << "DMR:" << endl;
+                        }
 
-                         XMLWriter xml;
-                         dmr.print_dap4(xml);
-                         cout << xml.get_doc() << endl;
+                        XMLWriter xml;
+                        dmr.print_dap4(xml);
+                        cout << xml.get_doc() << endl;
 
-                         print_data(dmr, print_rows);
+                        print_data(dmr, print_rows);
                     }
-                     catch (Error & e) {
-                         cerr << e.get_error_message() << endl;
-                         if (report_errors)
-                             return EXIT_FAILURE;
-                         continue;       // Goto the next URL or exit the loop.
-                     }
-                 }
+                    catch (Error &e) {
+                        cerr << e.get_error_message() << endl;
+                        if (report_errors)
+                            return EXIT_FAILURE;
+                        continue;       // Goto the next URL or exit the loop.
+                    }
+                }
             }
             else {
                 HTTPConnect http(RCReader::instance());
@@ -424,8 +404,8 @@ int main(int argc, char *argv[])
                     try {
                         HTTPResponse *r = http.fetch_url(url_string);
                         if (verbose) {
-                        	vector<string> *headers = r->get_headers();
-                        	copy(headers->begin(), headers->end(), ostream_iterator<string>(cout, "\n"));
+                            vector <string> *headers = r->get_headers();
+                            copy(headers->begin(), headers->end(), ostream_iterator<string>(cout, "\n"));
                         }
                         if (!read_data(r->get_stream())) {
                             continue;
@@ -433,7 +413,7 @@ int main(int argc, char *argv[])
                         delete r;
                         r = 0;
                     }
-                    catch (Error & e) {
+                    catch (Error &e) {
                         cerr << e.get_error_message() << endl;
                         if (report_errors)
                             return EXIT_FAILURE;
@@ -442,39 +422,30 @@ int main(int argc, char *argv[])
                 }
             }
 
-#if 0
-            else if (get_version) {
-                fprintf(stderr, "DAP version: %s, Server version: %s\n",
-                        url->request_protocol().c_str(),
-                        url->get_version().c_str());
-            }
-#endif
-
-            delete url;  url = 0;
+            delete url;
+            url = nullptr;
         }
     }
     catch (Error &e) {
+        delete url;
+        if (e.get_error_code() == malformed_expr) {
+            cerr << e.get_error_message() << endl;
+            usage(argv[0]);
+        }
+        else {
+            cerr << e.get_error_message() << endl;
 
-    	if(e.get_error_code() == malformed_expr){
-        	cerr << e.get_error_message() << endl;
-        	usage(argv[0]);
-    	}
-    	else {
-        	cerr << e.get_error_message() << endl;
-
-    	}
+        }
 
         cerr << "Exiting." << endl;
-        //return 1;
         return EXIT_FAILURE;
     }
     catch (exception &e) {
+        delete url;
         cerr << "C++ library exception: " << e.what() << endl;
         cerr << "Exiting." << endl;
-        //return 1;
         return EXIT_FAILURE;
     }
 
-    //return 0;
     return EXIT_SUCCESS;
 }
