@@ -34,16 +34,16 @@
 #include "D4EnumDefs.h"
 #include "XMLWriter.h"
 #include "debug.h"
-#include "GetOpt.h"
+
 
 #include "testFile.h"
 #include "dods-limits.h"
+#include "run_tests_cppunit.h"
 #include "test_config.h"
 
-static bool debug = false;
 
-#undef DBG
-#define DBG(x) do { if (debug) (x); } while(false);
+
+
 
 using namespace CppUnit;
 using namespace std;
@@ -383,43 +383,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (D4EnumTest);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: D4EnumTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = libdap::D4EnumTest::suite()->getTests();
-            unsigned int prefix_len = libdap::D4EnumTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = libdap::D4EnumTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<D4EnumTest>(argc, argv) ? 0: 1;
 }
