@@ -50,14 +50,16 @@
 #include "D4BaseTypeFactory.h"
 
 #include "GNURegex.h"
-#include "GetOpt.h"
+
 #include "util.h"
 #include "debug.h"
 
 #include "testFile.h"
+#include "run_tests_cppunit.h"
 #include "test_config.h"
 
-static bool debug = false;
+
+
 
 #undef DBG
 #define DBG(x) do { if (debug) {x;} } while(false)
@@ -115,6 +117,10 @@ public:
     // DAS, it will need to specialize the BaseType::transfer_attributes()
     // method.
     CPPUNIT_TEST_SUITE (DDSTest);
+
+    CPPUNIT_TEST(iterator_use_test_1);
+    CPPUNIT_TEST(iterator_use_test_2);
+
     CPPUNIT_TEST(transfer_attributes_test_1);
     CPPUNIT_TEST(transfer_attributes_test_2);
 
@@ -153,6 +159,74 @@ public:
     CPPUNIT_TEST(get_das_test_6);
 
     CPPUNIT_TEST_SUITE_END();
+    
+    void iterator_use_test_1() {
+        DBG(cerr << "iterator_use_test_1" << endl);
+        
+        dds1->parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dds");
+        DAS das;
+        das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
+        dds1->transfer_attributes(&das);
+        
+        // in this loop count the variables and accumulate their names. This tests using the
+        // old and new way of iterating over the BaseType pointers. jhrg 2/4/22
+        int old_count = 0;
+        string old_names = "";
+        for (DDS::Vars_iter i = dds1->var_begin(), e = dds1->var_end(); i != e; ++i) {
+            ++old_count;
+            old_names.append((*i)->name());
+        }
+
+        DBG(cerr << "old_count: " << old_count << endl);
+        DBG(cerr << "old_names: " << old_names << endl);
+        
+        int new_count = 0;
+        string new_names = "";
+        for (auto &btp: dds1->variables()) {
+            ++new_count;
+            new_names.append(btp->name());
+        }
+
+        DBG(cerr << "new_count: " << new_count << endl);
+        DBG(cerr << "new_names: " << new_names << endl);
+        
+        CPPUNIT_ASSERT_MESSAGE("The number of variable should be the same", old_count == new_count);
+        CPPUNIT_ASSERT_MESSAGE("The names of the variables should be the same", old_names == new_names);
+    }
+
+    void iterator_use_test_2() {
+        DBG(cerr << "iterator_use_test_2" << endl);
+
+        dds1->parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dds");
+        DAS das;
+        das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
+        dds1->transfer_attributes(&das);
+
+        // in this loop count the variables and accumulate their names. This tests using the
+        // old and new way of iterating over the BaseType pointers. jhrg 2/4/22
+        int old_count = 0;
+        string old_names = "";
+        for (DDS::Vars_riter i = dds1->var_rbegin(), e = dds1->var_rend(); i != e; ++i) {
+            ++old_count;
+            old_names.append((*i)->name());
+        }
+
+        DBG(cerr << "old_count: " << old_count << endl);
+        DBG(cerr << "old_names: " << old_names << endl);
+
+        int new_count = 0;
+        string new_names = "";
+        for (auto i = dds1->variables().rbegin(), e = dds1->variables().rend(); i != e; ++i) {
+            ++new_count;
+            new_names.append((*i)->name());
+        }
+
+        DBG(cerr << "new_count: " << new_count << endl);
+        DBG(cerr << "new_names: " << new_names << endl);
+
+        CPPUNIT_ASSERT_MESSAGE("The number of variable should be the same", old_count == new_count);
+        CPPUNIT_ASSERT_MESSAGE("The names of the variables should be the same", old_names == new_names);
+    }
 
     void transfer_attributes_test_1()
     {
@@ -554,7 +628,7 @@ public:
             das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
             dds.transfer_attributes(&das);
 
-            auto_ptr<DAS> new_das(dds.get_das());
+            unique_ptr<DAS> new_das(dds.get_das());
 
             string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
             ostringstream oss;
@@ -586,8 +660,8 @@ public:
 
             parser.intern(ifs, &dmr);
 
-            auto_ptr<DDS> dds(dmr.getDDS());
-            auto_ptr<DAS> das(dds->get_das());
+            unique_ptr<DDS> dds(dmr.getDDS());
+            unique_ptr<DAS> das(dds->get_das());
 
             string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/dmr-testsuite/coads_climatology.nc.full.dmr.das");
             ostringstream oss;
@@ -613,7 +687,7 @@ public:
             das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_var");
             dds.transfer_attributes(&das);
 
-            auto_ptr<DAS> new_das(dds.get_das());
+            unique_ptr<DAS> new_das(dds.get_das());
 
             string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_var");
             ostringstream oss;
@@ -639,7 +713,7 @@ public:
             das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_global");
             dds.transfer_attributes(&das);
 
-            auto_ptr<DAS> new_das(dds.get_das());
+            unique_ptr<DAS> new_das(dds.get_das());
 
             string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_global");
             ostringstream oss;
@@ -667,8 +741,8 @@ public:
 
             parser.intern(ifs, &dmr);
 
-            auto_ptr<DDS> dds(dmr.getDDS());
-            auto_ptr<DAS> das(dds->get_das());
+            unique_ptr<DDS> dds(dmr.getDDS());
+            unique_ptr<DAS> das(dds->get_das());
 
             string baseline = read_test_baseline(string(TEST_SRC_DIR) +  "/dmr-to-dap2-testsuite/1A.GPM.GMI.COUNT2014v3.20160105.h5.dmrpp.dmr.baseline");
             ostringstream oss;
@@ -695,8 +769,8 @@ public:
 
             parser.intern(ifs, &dmr);
 
-            auto_ptr<DDS> dds(dmr.getDDS());
-            auto_ptr<DAS> das(dds->get_das());
+            unique_ptr<DDS> dds(dmr.getDDS());
+            unique_ptr<DAS> das(dds->get_das());
 
             string baseline = read_test_baseline(string(TEST_SRC_DIR) +  "/dmr-to-dap2-testsuite/hacked.dmrpp.dmr.baseline");
             ostringstream oss;
@@ -720,48 +794,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION(DDSTest);
 
 int main(int argc, char *argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-
-        case 'h': {     // help - show test names
-            cerr << "Usage: DDSTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = libdap::DDSTest::suite()->getTests();
-            unsigned int prefix_len = libdap::DDSTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            return 1;
-            break;
-        }
-
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = libdap::DDSTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<libdap::DDSTest>(argc, argv) ? 0: 1;
 }
-
