@@ -43,15 +43,10 @@
 #include "SignalHandler.h"	// Needed to clean up this singleton.
 #endif
 #include "RCReader.h"		// ditto
-#include"GetOpt.h"
-
-// #define DODS_DEBUG
 
 #include "debug.h"
-
-#if defined(DODS_DEBUG) || defined(DODS_DEBUG2)
-#include <iterator>
-#endif
+#include "run_tests_cppunit.h"
+#include "test_config.h"
 
 using namespace CppUnit;
 using namespace std;
@@ -61,11 +56,6 @@ using namespace std;
 #define W_OK 2
 #endif
 
-static bool debug = false;
-
-#undef DBG
-#define DBG(x) do { if (debug) (x); } while(false);
-
 namespace libdap {
 
 inline static int file_size(string name)
@@ -75,14 +65,6 @@ inline static int file_size(string name)
     return s.st_size;
 }
 
-#if 0
-inline static void
-print_entry(HTTPCache *, HTTPCacheTable::CacheEntry **e)
-{
-    cerr << "Entry: " << (*e)->get_cachename() << endl;
-}
-#endif
-
 // Note that because this test class uses the fixture 'hc' we must always
 // force access to the single user/process lock for the cache. This is
 // because a fixture is always created (by setUp) *before* the body of the
@@ -129,6 +111,7 @@ public:
         http_conn = 0;
         DBG2(cerr << "Entering the HTTPCacheTest dtor... ");DBG2(cerr << "exiting." << endl);
     }
+
 #if 0
     static inline bool
     is_hop_by_hop_header(const string &header) {
@@ -140,6 +123,7 @@ public:
         || header.find("Upgrade") != string::npos;
     }
 #endif
+
     void setUp()
     {
         // Called before every test.
@@ -511,6 +495,7 @@ public:
         }
 
 #ifdef DODS_DEBUG
+#include <iterator>
         std::ostream_iterator<string> out_it(std::cerr, "\n");
         cerr << "Cached headers: ";
         std::copy(cached_headers.begin(), cached_headers.end(), out_it);
@@ -543,7 +528,7 @@ public:
         try {
             delete hc;
             hc = 0;
-            auto_ptr<HTTPCache> gc(new HTTPCache("cache-testsuite/gc_cache", true));
+            unique_ptr<HTTPCache> gc(new HTTPCache("cache-testsuite/gc_cache", true));
             DBG(cerr << "get_cache_root: " << gc->get_cache_root() << endl);
 
             HTTPResponse *rs = http_conn->fetch_url(localhost_url);
@@ -575,7 +560,7 @@ public:
     void purge_cache_and_release_cached_response_test()
     {
         try {
-            auto_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
+            unique_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
             DBG(cerr << "get_cache_root: " << pc->get_cache_root() << endl);
 
             time_t now = time(0);
@@ -686,7 +671,7 @@ public:
     void get_conditional_response_headers_test()
     {
         try {
-            auto_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/header_cache", true));
+            unique_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/header_cache", true));
             DBG(cerr << "get_cache_root: " << c->get_cache_root() << endl);
 
             CPPUNIT_ASSERT(c->get_cache_root() == "cache-testsuite/header_cache/");
@@ -723,7 +708,7 @@ public:
     void update_response_test()
     {
         try {
-            auto_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/singleton_cache", true));
+            unique_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/singleton_cache", true));
             DBG(cerr << "get_cache_root: " << c->get_cache_root() << endl);
 
             if (!c->is_url_in_cache(localhost_url)) {
@@ -786,7 +771,7 @@ public:
     void interrupt_test()
     {
         try {
-            auto_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/singleton_cache", true));
+            unique_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/singleton_cache", true));
             string coads = "http://test.opendap.org/dap/data/nc/coads_climatology.nc";
             if (!c->is_url_in_cache(coads)) {
                 HTTPResponse *rs = http_conn->fetch_url(coads);
@@ -807,7 +792,7 @@ public:
         string jan = "http://test.opendap.org/dap/data/nc/jan.nc.dds";
         string feb = "http://test.opendap.org/dap/data/nc/feb.nc.dds";
         try {
-            auto_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
+            unique_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
 #if 0
             // This broke Fedora ppc64le system with XFS system
             CPPUNIT_ASSERT(pc->d_http_cache_table->d_block_size == 4096);
@@ -856,7 +841,7 @@ public:
         // performed. The feb URL should have been deleted.
 
         try {
-            auto_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
+            unique_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
             CPPUNIT_ASSERT(!pc->is_url_in_cache(feb));
         }
         catch (Error &e) {
@@ -872,50 +857,10 @@ CPPUNIT_TEST_SUITE_REGISTRATION (HTTPCacheTest);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: HTTPCacheTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = libdap::HTTPCacheTest::suite()->getTests();
-            unsigned int prefix_len = libdap::HTTPCacheTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
     // Run cleanup here, so that the first run works (since this code now
     // sets up the tests).
     // This gives valgrind fits...
     system("cd cache-testsuite && ./cleanup.sh");
 
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = libdap::HTTPCacheTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<libdap::HTTPCacheTest>(argc, argv) ? 0: 1;
 }
-
