@@ -38,19 +38,12 @@
 
 #include "debug.h"
 
+#include "run_tests_cppunit.h"
 #include "test_config.h"
-#include "GetOpt.h"
 
 using namespace CppUnit;
 using namespace std;
 
-// FIXME By default this should be false, but we're tracking down a
-//  potential bug in this code or test. jhrg 1/28/21
-static bool debug = false;
-
-#undef DBG
-#define DBG(x) do { if (debug) (x); } while(false);
-
 #define prolog std::string("HTTPConnectTest::").append(__func__).append("() - ")
 
 namespace libdap {
@@ -757,44 +750,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (HTTPConnectTest);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: HTTPConnectTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = libdap::HTTPConnectTest::suite()->getTests();
-            unsigned int prefix_len = libdap::HTTPConnectTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = libdap::HTTPConnectTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<libdap::HTTPConnectTest>(argc, argv) ? 0: 1;
 }
