@@ -38,21 +38,18 @@
 #include <string>
 #include <sstream>
 
-#include "GetOpt.h"
-
 #include "GNURegex.h"
 
 #include "Error.h"
 #include "mime_util.h"
 #include "debug.h"
+#include "run_tests_cppunit.h"
 #include "test_config.h"
 
 using namespace CppUnit;
 using namespace std;
 using namespace libdap;
 
-static bool debug = false;
-
 class cgiUtilTest: public TestFixture {
 private:
 
@@ -135,7 +132,7 @@ Content-Description: dods_dds\r\n\
 
         oss.str("");
         set_mime_text(oss, dods_dds, "dods-test/0.00");
-        DBG(cerr << "DODS DDS" << endl << oss);
+        DBG(cerr << "DODS DDS" << endl << oss.str());
         CPPUNIT_ASSERT(re_match(r2, oss.str()));
 
         struct tm tm = { 0, 0, 0, 1, 0, 100, 0, 0, 0, 0, 0 }; // 1 Jan 2000
@@ -222,44 +219,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (cgiUtilTest);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: cgiUtilTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = cgiUtilTest::suite()->getTests();
-            unsigned int prefix_len = cgiUtilTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = cgiUtilTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<cgiUtilTest>(argc, argv) ? 0: 1;
 }
