@@ -40,17 +40,14 @@
 #include "XDRStreamMarshaller.h"
 #include "XDRFileUnMarshaller.h"
 #include "XDRStreamUnMarshaller.h"
-#include "GetOpt.h"
-//#include "Locker.h"
+
 #include "debug.h"
 
+#include "run_tests_cppunit.h"
+#include "test_config.h"
+
 int test_variable_sleep_interval = 0; // Used in Test* classes for testing timeouts.
 
-static bool debug = false;
-
-#undef DBG
-#define DBG(x) do { if (debug) {x;} } while(false)
-
 using namespace CppUnit;
 using namespace std;
 
@@ -193,7 +190,7 @@ public:
         db.resize(arr->length());
         for (int i = 0; i < arr->length(); ++i)
             db[i] = 126;
-        arr->value(&db[0]);
+        arr->value(db.data());
 
         // Array of Float32
         a_f32 = new TestFloat32("a_f32");
@@ -207,7 +204,7 @@ public:
         d_f32.resize(arr->length());
         for (int i = 0; i < arr->length(); ++i)
             d_f32[i] = 126.126;
-        arr_f32->value(&d_f32[0]);
+        arr_f32->value(d_f32.data());
 
         // Array of Float64
         a_f64 = new TestFloat64("a_f64");
@@ -221,7 +218,7 @@ public:
         d_f64.resize(arr->length());
         for (int i = 0; i < arr->length(); ++i)
             d_f64[i] = 1260.0126;
-        arr_f64->value(&d_f64[0]);
+        arr_f64->value(d_f64.data());
 
         s = new TestStructure("s");
         s->add_var(i32);
@@ -370,7 +367,7 @@ public:
 
             dods_byte fdb[farr.length() * sizeof(dods_byte)];
             farr.value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], farr.length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), farr.length() * sizeof(dods_byte)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -431,7 +428,7 @@ public:
             fsarr_p->value(fdb);
 
             CPPUNIT_ASSERT(fsarr_p->length() == arr->length());
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], fsarr_p->length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), fsarr_p->length() * sizeof(dods_byte)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -498,7 +495,7 @@ public:
 
             dods_byte fdb[tg.get_array()->length() * sizeof(dods_byte)];
             tg.get_array()->value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], tg.get_array()->length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), tg.get_array()->length() * sizeof(dods_byte)));
 
             // Should test the map values here, but skip that for now...
         }
@@ -569,7 +566,7 @@ public:
                 CPPUNIT_ASSERT(arr_p);
                 arr_p->value(fdb);
                 CPPUNIT_ASSERT(arr_p->length() == arr->length());
-                CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], arr_p->length() * sizeof(dods_byte)));
+                CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), arr_p->length() * sizeof(dods_byte)));
                 Sequence *seq_p = dynamic_cast<Sequence *>((*row)[2]);
                 CPPUNIT_ASSERT(seq_p);
                 unsigned int num_rows_sub = seq_p->number_of_rows();
@@ -712,7 +709,7 @@ public:
 
             dods_byte fdb[arr->length() * sizeof(dods_byte)];
             farr.value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], farr.length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), farr.length() * sizeof(dods_byte)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -878,8 +875,8 @@ public:
             CPPUNIT_ASSERT(farr.length() == arr->length());
 
             vector<dods_float32> fd_f32(arr->length());
-            farr.value(&fd_f32[0]);
-            CPPUNIT_ASSERT(!memcmp((void *) &fd_f32[0], (void *) &d_f32[0], farr.length() * sizeof(dods_float32)));
+            farr.value(fd_f32.data());
+            CPPUNIT_ASSERT(!memcmp((void *) fd_f32.data(), (void *) d_f32.data(), farr.length() * sizeof(dods_float32)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -968,8 +965,8 @@ public:
             CPPUNIT_ASSERT(farr.length() == arr->length());
 
             vector<dods_float64> fd_f64(arr->length());
-            farr.value(&fd_f64[0]);
-            CPPUNIT_ASSERT(!memcmp((void *) &fd_f64[0], (void *) &d_f64[0], farr.length() * sizeof(dods_float64)));
+            farr.value(fd_f64.data());
+            CPPUNIT_ASSERT(!memcmp((void *) fd_f64.data(), (void *) d_f64.data(), farr.length() * sizeof(dods_float64)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -1079,7 +1076,7 @@ public:
             CPPUNIT_ASSERT(fsarr_p->length() == arr->length());
             dods_byte fdb[fsarr_p->length() * sizeof(dods_byte)];
             fsarr_p->value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], fsarr_p->length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), fsarr_p->length() * sizeof(dods_byte)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -1150,7 +1147,7 @@ public:
 
             dods_byte fdb[tg.get_array()->length() * sizeof(dods_byte)];
             tg.get_array()->value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], tg.get_array()->length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), tg.get_array()->length() * sizeof(dods_byte)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -1223,7 +1220,7 @@ public:
                 CPPUNIT_ASSERT(arr_p);
                 arr_p->value(fdb);
                 CPPUNIT_ASSERT(arr_p->length() == arr->length());
-                CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], arr_p->length() * sizeof(dods_byte)));
+                CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), arr_p->length() * sizeof(dods_byte)));
                 Sequence *seq_p = dynamic_cast<Sequence *>((*row)[2]);
                 CPPUNIT_ASSERT(seq_p);
                 unsigned int num_rows_sub = seq_p->number_of_rows();
@@ -1331,20 +1328,20 @@ public:
 
             dods_byte fdb[arr->length() * sizeof(dods_byte)];
             farr.value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], farr.length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), farr.length() * sizeof(dods_byte)));
 
             // now get three more arrays of the same size
             farr.deserialize(um, &dds, false);
             farr.value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], farr.length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), farr.length() * sizeof(dods_byte)));
 
             farr.deserialize(um, &dds, false);
             farr.value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], farr.length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), farr.length() * sizeof(dods_byte)));
 
             farr.deserialize(um, &dds, false);
             farr.value(fdb);
-            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) &db[0], farr.length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fdb, (void *) db.data(), farr.length() * sizeof(dods_byte)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -1477,12 +1474,12 @@ public:
 
             dods_float32 fd_32[arr->length() * sizeof(dods_float32)];
             farr.value(fd_32);
-            CPPUNIT_ASSERT(!memcmp((void *) fd_32, (void *) &d_f32[0], farr.length() * sizeof(dods_float32)));
+            CPPUNIT_ASSERT(!memcmp((void *) fd_32, (void *) d_f32.data(), farr.length() * sizeof(dods_float32)));
 
             // now get three more arrays of the same size
             farr.deserialize(um, &dds, false);
             farr.value(fd_32);
-            CPPUNIT_ASSERT(!memcmp((void *) fd_32, (void *) &d_f32[0], farr.length() * sizeof(dods_byte)));
+            CPPUNIT_ASSERT(!memcmp((void *) fd_32, (void *) d_f32.data(), farr.length() * sizeof(dods_byte)));
         }
         catch (Error &e) {
             string err = "failed:" + e.get_error_message();
@@ -1618,50 +1615,9 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION (MarshallerTest);
 
-} // namepsace libdap
+} // namespace libdap
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: MarshallerTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = libdap::MarshallerTest::suite()->getTests();
-            unsigned int prefix_len = libdap::MarshallerTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << endl;
-            test = libdap::MarshallerTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    xmlMemoryDump();
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<libdap::MarshallerTest>(argc, argv) ? 0: 1;
 }
