@@ -27,33 +27,19 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "parser.h"
-
-#include "GetOpt.h"
+#include "run_tests_cppunit.h"
+#include "test_config.h"
 
 using namespace CppUnit;
 using namespace libdap;
 using namespace std;
 
-static bool debug = false;
-
 class parserUtilTest: public TestFixture {
 private:
 
 public:
-    parserUtilTest()
-    {
-    }
-    ~parserUtilTest()
-    {
-    }
-
-    void setUp()
-    {
-    }
-
-    void tearDown()
-    {
-    }
+    parserUtilTest() = default;
+    ~parserUtilTest() = default;
 
     CPPUNIT_TEST_SUITE (parserUtilTest);
 
@@ -146,45 +132,5 @@ CPPUNIT_TEST_SUITE_REGISTRATION (parserUtilTest);
 
 int main(int argc, char*argv[])
 {
-    GetOpt getopt(argc, argv, "dh");
-    int option_char;
-
-    while ((option_char = getopt()) != -1)
-        switch (option_char) {
-        case 'd':
-            debug = 1;  // debug is a static global
-            break;
-        case 'h': {     // help - show test names
-            cerr << "Usage: parserUtilTest has the following tests:" << endl;
-            const std::vector<Test*> &tests = parserUtilTest::suite()->getTests();
-            unsigned int prefix_len = parserUtilTest::suite()->getName().append("::").length();
-            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
-                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
-            }
-            break;
-        }
-        default:
-            break;
-        }
-
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    bool wasSuccessful = true;
-    string test = "";
-    int i = getopt.optind;
-    if (i == argc) {
-        // run them all
-        wasSuccessful = runner.run("");
-    }
-    else {
-        for (; i < argc; ++i) {
-            if (debug) cerr << "Running " << argv[i] << std::endl;
-            test = parserUtilTest::suite()->getName().append("::").append(argv[i]);
-            wasSuccessful = wasSuccessful && runner.run(test);
-        }
-    }
-
-    return wasSuccessful ? 0 : 1;
+    return run_tests<parserUtilTest>(argc, argv) ? 0: 1;
 }
-
